@@ -1,3 +1,8 @@
+package Exception::BadArguments::InvalidJSON;
+{
+  $Exception::BadArguments::InvalidJSON::VERSION = '0.9';
+}
+use base qw(Exception::BadArguments);
 
 =head1 Name
 
@@ -7,7 +12,7 @@ qbit::StringUtils - Functions to manipulate strings.
 
 package qbit::StringUtils;
 {
-  $qbit::StringUtils::VERSION = '0.7';
+  $qbit::StringUtils::VERSION = '0.9';
 }
 
 use strict;
@@ -29,7 +34,7 @@ BEGIN {
     our (@EXPORT, @EXPORT_OK);
 
     @EXPORT = qw(
-      html_encode html_decode uri_escape check_email idn_to_unicode get_domain to_json from_json format_number
+      html_encode html_decode uri_escape check_email idn_to_unicode get_domain to_json from_json format_number fix_utf
       );
     @EXPORT_OK = @EXPORT;
 }
@@ -323,23 +328,16 @@ sub from_json($) {
 
     utf8::encode($text);
     my $result;
-    eval {
-        $result = JSON::XS->new->utf8->allow_nonref->decode($text);
-    };
+    eval {$result = JSON::XS->new->utf8->allow_nonref->decode($text);};
 
     if (!$@) {
         return $result;
     } else {
         $text = '' if !defined $text;
-        throw gettext(
-            "Error in from_json().\n"
-            . "Error message:\n"
-            . "%s\n"
-            . "Input:\n"
-            . "'%s'\n",
-            $@,
-            $original_text,
-        );
+        my ($error) = ($@ =~ m'(.+) at /');
+        $error ||= $@;
+        throw Exception::BadArguments::InvalidJSON gettext("Error in from_json: %s\n" . "Input:\n" . "'%s'\n", $error,
+            $original_text,);
     }
 }
 
@@ -423,4 +421,30 @@ sub format_number($%) {
     return "$int$frac";
 }
 
+=head2 fix_utf
+
+B<Arguments:>
+
+=over
+
+=item
+
+B<$string> - string.
+
+=back
+
+Convert $string to perl utf8 string if it is without utf8 flag;
+
+B<Return value:> string with utf8 flag.
+
+=cut
+
+sub fix_utf {
+    my ($string) = @_;
+
+    utf8::decode($string) unless utf8::is_utf8($string);
+
+    return $string;
+}
+
 1;
